@@ -72,7 +72,7 @@ void DownloadManager::parseVideoPage() {
 }
 
 void DownloadManager::pauseDownload() {
-        downloadReply->abort();
+    downloadReply->abort();
 }
 
 void DownloadManager::cancelDownload() {
@@ -119,12 +119,28 @@ void DownloadManager::performDownload(const QByteArray &videoUrl) {
 
     downloadReply = nam->get(request);
     emit statusChanged("Downloading");
-    connect(downloadReply, SIGNAL(downloadProgress(qint64, qint64)), this, SIGNAL(progressChanged(qint64,qint64)));
+    downloadTime.start();
+    connect(downloadReply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateProgress(qint64,qint64)));
     connect(downloadReply, SIGNAL(finished()), this, SLOT(downloadFinished()));
     connect(downloadReply, SIGNAL(readyRead()), this, SLOT(downloadReadyRead()));
 }
 
+void DownloadManager::updateProgress(qint64 bytesReceived, qint64 bytesTotal) {
+    double speed = bytesReceived * 1000.0 / downloadTime.elapsed();
+    QString unit;
+    if (speed < 1024) {
+        unit = "bytes/sec";
+    } else if (speed < 1024*1024) {
+        speed /= 1024;
+        unit = "kB/s";
+    } else {
+        speed /= 1024*1024;
+        unit = "MB/s";
+    }
 
+    emit progressChanged(bytesReceived, bytesTotal, QString::fromLatin1("%1 %2")
+                         .arg(speed, 3, 'f', 1).arg(unit));
+}
 
 void DownloadManager::downloadFinished() {
     QUrl redirect = downloadReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
@@ -155,7 +171,7 @@ void DownloadManager::downloadFinished() {
                 else {
                     filename = filename.replace(filename.lastIndexOf("(" + QByteArray::number(num - 1) + ")"), 3, "(" + QByteArray::number(num) + ")");
                 }
-//                qDebug() << filename;
+                //                qDebug() << filename;
                 fileSaved = output.rename(filename);
                 num++;
             }
