@@ -38,7 +38,6 @@ function getArchiveVideos() {
 
 function moveToArchive(video) {
     Settings.addVideoToArchive(video);
-    Settings.removeStoredDownload(video.filePath);
     archiveModel.insert(0, video);
     downloadModel.remove(downloadModel.currentDownload);
     downloadModel.getNextDownload();
@@ -115,7 +114,7 @@ function loadAccountView() {
         loader.item.favourites.connect(loadVideos);
         loader.item.playlists.connect(loadPlaylists);
         loader.item.subscriptions.connect(loadSubscriptions);
-        notificationArea.addTitle("My Channel");
+        notificationArea.addTitle(qsTr("My Channel"));
         windowView.incrementCurrentIndex();
     }
     else {
@@ -129,7 +128,7 @@ function loadArchiveView() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "ArchiveListView.qml";
-    notificationArea.addTitle("Archive");
+    notificationArea.addTitle(qsTr("Archive"));
     windowView.incrementCurrentIndex();
 }
 
@@ -168,7 +167,7 @@ function loadPlaylists() {
     windowView.currentItem.visible = false;
     loader.source = "PlaylistsView.qml";
     loader.item.goToPlaylist.connect(loadPlaylistVideos);
-    notificationArea.addTitle("My Playlists");
+    notificationArea.addTitle(qsTr("My Playlists"));
     windowView.incrementCurrentIndex();
 }
 
@@ -178,7 +177,7 @@ function loadSubscriptions() {
     loader.source = "SubscriptionsView.qml";
     loader.item.goToUserVideos.connect(loadUserVideos);
     loader.item.goToNewSubVideos.connect(loadVideos);
-    notificationArea.addTitle("My Subscriptions");
+    notificationArea.addTitle(qsTr("My Subscriptions"));
     windowView.incrementCurrentIndex();
 }
 
@@ -191,7 +190,7 @@ function loadVideoInfo(video) {
     loader.item.authorClicked.connect(loadUserVideos);
     loader.item.search.connect(search);
     loader.item.setVideo(video);
-    notificationArea.addTitle("Video Info");
+    notificationArea.addTitle(qsTr("Video Info"));
     windowView.incrementCurrentIndex();
 }
 
@@ -200,7 +199,7 @@ function loadPlaybackView(videoList) {
     windowView.currentItem.visible = false;
     toggleControls(false);
     loader.source = "VideoPlaybackView.qml";
-    notificationArea.addTitle("Video Playback");
+    notificationArea.addTitle(qsTr("Video Playback"));
     loader.item.setPlaylist(videoList);
     windowView.incrementCurrentIndex();
     loader.item.playbackStopped.connect(stopPlaying);
@@ -210,7 +209,7 @@ function loadDownloads() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "DownloadListView.qml";
-    notificationArea.addTitle("Downloads");
+    notificationArea.addTitle(qsTr("Downloads"));
     windowView.incrementCurrentIndex();
 }
 
@@ -227,7 +226,7 @@ function youtubeSearch(query, order) {
 
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
                      + query.replace(" ", "+") + "&orderby=" + searchOrder);
-    loadVideos(videoFeed, "Search ('" + query + "')");
+    loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
 function search(query, order) {
